@@ -229,7 +229,8 @@ def plot_k2(kk, kk_many, frequencies_disp, frequencies_ft, f, data, data_project
     ax2.tick_params(axis='y', which='major', labelsize=15, width=2 , length=6, direction='in')
 
     plt.show()
-    plt.suptitle('Spectrum branches '+str(branches))
+    plt.title('Spectrum branches '+str(branches))
+    plt.tight_layout()
     fig.savefig('plot5_'+str(branches)+'.pdf', backend='pgf')
     return 
 
