@@ -274,8 +274,8 @@ if(plot_type==4):
         
         
     # this is to reshape spectra according to real branches
-    indexes, freqs_reshaped = util.get_real_branches(frequencies[0,:,:], EIGVECS, masses_uc, ks_path_many)
-    indexes, freqs_disp_reshaped = util.get_real_branches(frequencies_disp[0,:,:], EIGVECS_0K, masses_uc, ks_path_many)
+    indexes, freqs_reshaped, eigvecs_list_sorted = util.get_real_branches(frequencies[0,:,:], EIGVECS, masses_uc, ks_path_many)
+    indexes, freqs_disp_reshaped, eigvecs_disp_list_sorted = util.get_real_branches(frequencies_disp[0,:,:], EIGVECS_0K, masses_uc, ks_path_many)
     frequencies_reshaped, frequencies_disp_reshaped  = np.copy(frequencies), np.copy(frequencies_disp)
     frequencies_reshaped[0,:,:], frequencies_disp_reshaped[0,:,:] = freqs_reshaped, freqs_disp_reshaped
 
@@ -388,9 +388,9 @@ if(plot_type==40):
 # =============================================================================
    
     # this is to reshape spectra according to real branches
-    indexes, freqs_reshaped = util.get_real_branches(frequencies[0,:,:], EIGVECS, masses_uc, ks_path_many)
-    indexes, freqs_disp_reshaped = util.get_real_branches(frequencies_disp[0,:,:], EIGVECS_0K, masses_uc, ks_path_many)
-    indexes, freqs_MD_reshaped = util.get_real_branches(frequencies_MD[0,:,:], EIGVECS_MD, masses_uc, ks_path)
+    indexes, freqs_reshaped, eigvecs_list_sorted = util.get_real_branches(frequencies[0,:,:], EIGVECS, masses_uc, ks_path_many)
+    indexes, freqs_disp_reshaped, eigvecs_disp_list_sorted = util.get_real_branches(frequencies_disp[0,:,:], EIGVECS_0K, masses_uc, ks_path_many)
+    indexes, freqs_MD_reshaped, eigvecs_MD_list_sorted = util.get_real_branches(frequencies_MD[0,:,:], EIGVECS_MD, masses_uc, ks_path)
     frequencies_reshaped, frequencies_disp_reshaped , frequencies_MD_reshaped = np.copy(frequencies), np.copy(frequencies_disp), np.copy(frequencies_MD)
     frequencies_reshaped[0,:,:], frequencies_disp_reshaped[0,:,:], frequencies_MD_reshaped[0,:,:] = freqs_reshaped, freqs_disp_reshaped, freqs_MD_reshaped
 
@@ -488,8 +488,8 @@ if(plot_type==5):
 
 
     #this is to reshape spectra according to real branches
-    indexes, freqs_reshaped = util.get_real_branches(frequencies, EIGVECS_0K, masses_uc, ks_path_many)
-    indexes_0K, freqs_disp_reshaped = util.get_real_branches(frequencies_disp, EIGVECS_0K, masses_uc, ks_path_many)
+    indexes, freqs_reshaped, eigvecs_list_sorted = util.get_real_branches(frequencies, EIGVECS_0K, masses_uc, ks_path_many)
+    indexes_0K, freqs_disp_reshaped, eigvecs_disp_list_sorted = util.get_real_branches(frequencies_disp, EIGVECS_0K, masses_uc, ks_path_many)
     
     frequencies_reshaped, frequencies_disp_reshaped  = np.copy(frequencies), np.copy(frequencies_disp)
     frequencies_reshaped, frequencies_disp_reshaped = freqs_reshaped, freqs_disp_reshaped
