@@ -520,20 +520,21 @@ def get_real_branches(freqs, eigvecs, masses, ks):
                     else:
                         dot[i,max_index] = 0
                             
-
         maxima = np.max(dot, axis=1)
         for l in range(num_branches):
             index = int(np.argwhere(dot[l,:] == maxima[l]))
             indexes.append(index)
             new_indexes = indexes #update new indexes
-            
+
         all_indexes.append(indexes)    
 
     freqs_sorted = np.copy(freqs)
+    eigvecs_sorted = np.copy(eigvecs)
     for j in range(1,num_ks):
         freqs_sorted[:,j] = freqs[all_indexes[j],j]
+        eigvecs_sorted[j] = eigvecs[j][:,all_indexes[j]]
     
-    return np.array(all_indexes), freqs_sorted
+    return np.array(all_indexes), freqs_sorted, np.array(eigvecs_sorted)
 
 
 def get_real_branches_old(freqs, eigvecs, masses, ks):
@@ -917,6 +918,17 @@ def get_Scells(H, R0):
         Scells[c] = R0 + displ[c]     
     return Scells
 
+# def get_Scells2(H, S0):
+#     N = len(S0)
+#     x1 = np.arange(-1,2)
+#     comb = np.array(np.meshgrid(x1,x1,x1)).T.reshape(-1,3)
+    
+#     displ = comb
+#     Scells = np.zeros((27, N, 3))
+#     for c in range(27):
+#         Scells[c] = S0 + displ[c]     
+#     return Scells
+
 def R_matrix2(N1,N2,N3,tot_atoms_uc,R0):
     """
     returns the R matrix
@@ -965,6 +977,69 @@ def R_matrix(N1,N2,N3,tot_atoms_uc,R0, H):
         
     return R_matrix_old, R_matrix_new# *0.529177249
 
+def R_matrix_multiplicity(N1,N2,N3,tot_atoms_uc,R0, H, tolerance=1.01):
+    """
+    returns the R matrix with multiplicities!
+    """
+    N1N2N3 = N1 * N2 * N3
+    N = len(R0[:,0])
+    Scells = get_Scells(H, R0)
+    # Scells2 = get_Scells2(H, S0)    
+    
+    R_matrix_new = []
+
+    count = 0
+    for i in range(tot_atoms_uc):
+        atom_origin = R0[i*N1N2N3]
+        row = []
+        for j in range(N):
+            dist_Scells_vec = Scells[:,j,:] - atom_origin
+            dist_Scells = np.linalg.norm(dist_Scells_vec, axis=1)
+            min_dist = np.min(dist_Scells, axis=0)
+            found_min_dist = np.argwhere( dist_Scells <= tolerance*min_dist)
+            row.append(Scells[found_min_dist,j,:] - atom_origin)
+        row = np.array(row)
+        R_matrix_new.append(row)
+    
+    return R_matrix_new# *0.529177249
+
+
+def get_D_multiplicity(k, K,N1,N2,N3,R0,masses,tot_atoms_uc, H):
+    """
+    New version of get_D, with multiplicity. Eigenvectors should be fine now.
+    Its a total delirium.
+    
+    builds the dynamical matrix
+    expects forces in 1/amu * ev / A**2
+    returns Thz**2
+    """
+    N1N2N3 = N1 * N2 * N3
+    N = N1N2N3*tot_atoms_uc
+    
+    Rnew = R_matrix_multiplicity(N1,N2,N3,tot_atoms_uc, R0,  H)
+    #prepare kdotr
+    exp_coeff = np.zeros((tot_atoms_uc*3,N*3), dtype=complex)
+    for i in range(tot_atoms_uc):
+        R = Rnew[i]
+        for j in range(N):
+            R_this_atom = R[j][:,0,:]
+            multiplicity = len(R_this_atom)
+            exp_phases = np.exp(1j*np.dot(R_this_atom, k))
+            exp_phase = np.sum(exp_phases)/multiplicity
+            # exp_phase = exp_phases[0]
+            
+            exp_coeff[i*3,j*3:j*3+3] = exp_phase
+            exp_coeff[i*3+1,j*3:j*3+3] = exp_phase
+            exp_coeff[i*3+2,j*3:j*3+3] = exp_phase
+        
+    mass_coeff = 1/np.sqrt(np.outer(masses, np.repeat(masses, N1N2N3)))
+    Dall = mass_coeff*K*exp_coeff
+    Da = np.reshape(Dall, (tot_atoms_uc*3,N,3))
+    D = np.zeros((tot_atoms_uc*3, tot_atoms_uc*3), dtype=complex)
+    for j in range(tot_atoms_uc):
+        D[:, j*3:j*3+3] = np.sum(Da[:,j*N1N2N3:(j+1)*N1N2N3,:], axis=1)
+        
+    return (D+D.conj().transpose())/2*0.964*10**(4) 
 
 
 def get_D(k, K,N1,N2,N3,R0,masses,tot_atoms_uc, H):
